# Set up a empty list of email addresses
# loop through the portal membership, pass memberId to check for
# Member role. If successful, check to see if the member has given
# permission to send email, and an area of business interest that 
# coincides with a content keyword. If successful, append the 
# list of email addresses and send them email

# Message Format
subject='The RealEstateBroker'
headtext='The following house(s) are available at this moment:\n\n'
foottext='You recieved this email because you signed up for our newsletter service. Wij hopen u hiermee van dienst geweest te zijn.\n\n'
remove='If you want to unsubscribe form this newsletter click here: \n' + context.portal_url()+ "/personalize_form\n\n"

today = DateTime().earliestTime()
lastWeek = (today-14)

# Start with an empty list, ready to be filled with the addressed
# of people we're dispatching to
mailList=[]
objects = []

# check that we can send email via the Zope standard Mail Host
mailhost=getattr(context, context.portal_url.superValues('Mail Host')[0].id)


# Iterate through all the site's users
for member in context.portal_membership.listMembers():
    memberId = member.id
    # Remember that a real name is not mandatory, so fall back to the username
    if (member.email !='') and member.newsletter:
        if member.fullname:
            memberName = member.fullname
        else:
            memberName = memberId

        results = context.portal_catalog(portal_type='REHome',
                                         created={'query' : lastWeek, 'range': 'min'},
                                         sort_on='created',
                                         sort_order='reverse')
        # filter out irrelevant houses
        for x in results:
            if str(x.price) > member.min_price and str(x.price) < member.max_price:
                if len(member.city) > 0:
                    for city in member.city:         
                        if str(city) == str(x.city):
                            objects.append(x)
                else:
                    objects.append(x)
  
        #Send email to current member with a list of available houses.
        if len(objects) > 0:
            #keep track of who got a message.
            mailList.append(member.email)
       
            # Generate a list of homes

                # Let's write an email:
            mMsg = 'Dear ' + memberName + ',\n\n'
            mMsg += headtext
            mMsg += 'Address                       City                Price    \n'
            mMsg += '---------------------------------------------------------------\n'
            for obj in objects:
                home = obj.getObject()
             
                address = str(home.address)[:30]
                if len(address) < 30:
                    alen = 30 - len(address)
                    address = address + alen*' '

                city = str(home.city)[:20]
                if len(city) < 20:
                    clen = 20 - len(city)
                    city = city + clen*' '
                   
                price = str(home.price)[:10]
                if len(price) < 10:
                    plen = 10 - len(price)
                    price = price + plen*' '               

                mMsg += '%s %s EUR. %s \n' % (address, city, price,)
            mMsg += '\n\n'
            mMsg += foottext
            mMsg += remove
            mTo = member.email
            mFrom = 'ahadi@zopeworks.nl'
            mSubj = subject
       
            # and send it
            mailhost.send(mMsg, mTo, mFrom, mSubj)

# The change in indentation signals the end of the loop, so we've
# now sent all the emails. Let's now send a confirmation that we've done it.

# We'll be building the email as a string again, but we have to convert our
# list data elements into a string before we can append the information

#recipients = string.join(mailList, sep='\n')

#bFrom = 'realestatebroker@domain.com'
#bTo = 'webmaster@domain.com'
#bMsg = 'The newsletter was sent to the following members: \n\n'
#bMsg += recipients + '\n\n'

#mailhost.send(bMsg, bTo, bFrom, '')

#return ('success', context, {'portal_status_message':context.REQUEST.get('portal_status_message', 'Mail sent.')})
